# JTCMake

[![Test](https://github.com/sugi-a/jtcmake/actions/workflows/python-package.yml/badge.svg)](https://github.com/sugi-a/jtcmake/actions)
[![Doctest](https://github.com/sugi-a/jtcmake/actions/workflows/sphinx-doctest.yml/badge.svg)](https://github.com/sugi-a/jtcmake/actions)
[![Python](https://img.shields.io/pypi/pyversions/jtcmake.svg)](https://pypi.org/project/jtcmake/)
[![PyPI Latest Release](https://img.shields.io/pypi/v/jtcmake.svg)](https://pypi.org/project/jtcmake/)
[![License](https://img.shields.io/pypi/l/jtcmake.svg)](https://github.com/sugi-a/jtcmake/blob/main/LICENSE)

JTCMake is a general purpose incremental build framework.


## Getting started

### Installation

```
$ pip install jtcmake
```

See also the official [documentation](https://sugi-a.github.io/jtcmake/).

